==> seedsui-react-5.5.92.tgz: package/lib/Input/PasswordStrong/index.js <==
var _excluded = ["value", "strong"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeString.js
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import locale from "./../../locale";
var PasswordStrong = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value,
      strong = _ref.strong,
      props = _objectWithoutProperties(_ref, _excluded);

  // 校验级别
  var lvl = 0;

  if (typeof strong === 'number') {
    lvl = strong;
  } else {
    lvl = value.safeLvl();
  } // 节点


  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  return /*#__PURE__*/React.createElement("ul", _extends({
    ref: rootRef
  }, props, {
    className: "input-password-strong lvl".concat(lvl).concat(props.className ? ' ' + props.className : '')
  }), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("div", {
    className: "input-password-strong-progress"
  }), /*#__PURE__*/React.createElement("span", {
    className: "input-password-strong-caption"
  }, locale('弱', 'low'))), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("div", {
    className: "input-password-strong-progress"
  }), /*#__PURE__*/React.createElement("span", {
    className: "input-password-strong-caption"
  }, locale('中', 'medium'))), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("div", {
    className: "input-password-strong-progress"
  }), /*#__PURE__*/React.createElement("span", {
    className: "input-password-strong-caption"
  }, locale('强', 'strong'))));
});
export default PasswordStrong;

==> seedsui-react-5.6.52.tgz: package/lib/Input/PasswordStrong/index.js <==
var _excluded = ["value", "strong"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeString.js
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import locale from "./../../locale";
var PasswordStrong = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value,
      strong = _ref.strong,
      props = _objectWithoutProperties(_ref, _excluded);

  // 校验级别
  var lvl = 0;

  if (typeof strong === 'number') {
    lvl = strong;
  } else {
    lvl = value.safeLvl();
  } // 节点


  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  return /*#__PURE__*/React.createElement("ul", _extends({}, props, {
    className: "input-password-strong lvl".concat(lvl).concat(props.className ? ' ' + props.className : ''),
    ref: rootRef
  }), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("div", {
    className: "input-password-strong-progress"
  }), /*#__PURE__*/React.createElement("span", {
    className: "input-password-strong-caption"
  }, locale('弱', 'low'))), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("div", {
    className: "input-password-strong-progress"
  }), /*#__PURE__*/React.createElement("span", {
    className: "input-password-strong-caption"
  }, locale('中', 'medium'))), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement("div", {
    className: "input-password-strong-progress"
  }), /*#__PURE__*/React.createElement("span", {
    className: "input-password-strong-caption"
  }, locale('强', 'strong'))));
});
export default PasswordStrong;
